@@ -59,3 +59,34 @@ export function drawColoredBagde(cr, bgColor, outlineColor, x, y, width, height)
         cr.stroke();
     }
 }
+
+/**
+ * Render highway shields to an array of Gdk.Paintables for a place.
+ *
+ * place: A Place instance
+ * maxNumShields: Maximum number of shields to render
+ * scaleFactor: Scale factor to render the shields at
+ */
+export function drawShieldsForPlace(place, maxNumShields, scaleFactor) {
+    const routes = place.routes;
+    let numProcessed = 0;
+
+    return routes.map(r => {
+                        if (numProcessed >= maxNumShields)
+                            return null;
+
+                        const paintable = r.shield.draw(r.ref ?? '',
+                                                        r.name ?? '',
+                                                        '',
+                                                        scaleFactor);
+
+                        if (paintable) {
+                            numProcessed++;
+
+                            return paintable;
+                        } else {
+                            return null;
+                        }
+                      })
+                 .filter(p => !!p);
+}
