@@ -201,6 +201,13 @@ const POI_CATEGORIES = [
                 icon:      'restaurant-symbolic',
                 keyValues: [['amenity=restaurant']]
             },
+            {
+                label:       _("Vegan & Vegetarian Restaurants"),
+                icon:        'restaurant-symbolic',
+                keyValues:   [['amenity=restaurant', '"diet:vegan"~"yes|only"'],
+                              ['amenity=restaurant', '"diet:vegetarian"~"yes|only"']],
+                deduplicate: true
+            },
             {
                 label:     _("Fast Food"),
                 icon:      'fast-food-symbolic',
@@ -358,7 +365,7 @@ const POI_CATEGORIES = [
             },
             {
                 label:       _("EV Charging"),
-                icon:        'electric-car-symbolic',
+                icon:        'ev-symbolic',
                 keyValues:   [['amenity=charging_station']],
                 deduplicate: true
             }
@@ -420,7 +427,7 @@ const POI_CATEGORIES = [
         subcategories: [
             {
                 label:     _("Parks"),
-                icon:      'tree-symbolic',
+                icon:      'tree-circle-symbolic',
                 keyValues: [['leisure=park']]
             },
             {
@@ -435,7 +442,7 @@ const POI_CATEGORIES = [
             },
             {
                 label:     _("Nature Reserves"),
-                icon:      'tree-symbolic',
+                icon:      'sprout-symbolic',
                 keyValues: [['leisure=nature_reserve']],
                 initialSearchRadius: 10000
             },
