@@ -17,9 +17,12 @@
  * Author: Jonas Danielson <jonas@threetimestwo.org>
  */
 
+import gettext from 'gettext';
+
 import Gdk from 'gi://Gdk';
 import GeocodeGlib from 'gi://GeocodeGlib';
 import Gio from 'gi://Gio';
+import GioUnix from 'gi://GioUnix';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
@@ -29,6 +32,8 @@ import {Application} from './application.js';
 import {PlaceFormatter} from './placeFormatter.js';
 import * as Utils from './utils.js';
 
+const _ = gettext.gettext;
+
 const _WEATHER_APPID = 'org.gnome.Weather';
 const _CLOCKS_APPID = 'org.gnome.clocks';
 
@@ -83,7 +88,7 @@ export class SendToDialog extends Gtk.Dialog {
             second string is the name of the app to add it to */
             let label = _("Add %s to %s");
 
-            let weatherInfo = Gio.DesktopAppInfo.new(_WEATHER_APPID + '.desktop');
+            let weatherInfo = GioUnix.DesktopAppInfo.new(_WEATHER_APPID + '.desktop');
             if (!weatherInfo) {
                 this._list.remove(this._weatherRow);
             } else {
@@ -92,7 +97,7 @@ export class SendToDialog extends Gtk.Dialog {
                 this._weatherIcon.icon_name = weatherInfo.get_icon().to_string();
             }
 
-            let clocksInfo = Gio.DesktopAppInfo.new(_CLOCKS_APPID + '.desktop');
+            let clocksInfo = GioUnix.DesktopAppInfo.new(_CLOCKS_APPID + '.desktop');
             if (!clocksInfo) {
                 this._list.remove(this._clocksRow);
             } else {
@@ -130,7 +135,10 @@ export class SendToDialog extends Gtk.Dialog {
 
         let formatter = new PlaceFormatter(place);
 
-        if (!place.isCurrentLocation)
+        /* don't show title for current location, and also not for raw
+         * coordinate places, as that would show the coordinate twice
+         */
+        if (!place.isRawCoordinates)
             lines.push(formatter.title);
 
         let details = formatter.getDetailsString();
@@ -138,8 +146,7 @@ export class SendToDialog extends Gtk.Dialog {
             lines.push(details);
         }
 
-        lines.push('%f, %f'.format(this._location.latitude.toFixed(5),
-                                   this._location.longitude.toFixed(5)));
+        lines.push(place.coordinatesDescription);
 
         return lines.join('\n');
     }
